@@ -11,26 +11,34 @@ import sys
 import traceback
 import time
 import gettext
-import ConfigParser
 
 import gobject
 import gtk
 import gtk.glade
 import gtk.gdk
 import pango
-import gnome, gnome.ui
+try:
+    import gnome, gnome.ui
+except ImportError:
+    haveGnomeSupport = False
+else:
+    haveGnomeSupport = True
 
 from glchess.defaults import *
 
 # Optionally use OpenGL support
 try:
     import gtk.gtkgl
+    import OpenGL
 except ImportError:
-    pass
+    haveGLSupport = False
+else:
+    haveGLSupport = True
 
 # Stop PyGTK from catching exceptions
 os.environ['PYGTK_FATAL_EXCEPTIONS'] = '1'
 
+import glchess.config
 import glchess.ui
 import dialogs
 
@@ -41,13 +49,14 @@ class GtkViewArea(gtk.DrawingArea):
     """Custom widget to render an OpenGL scene"""
     # The view this widget is rendering
     view = None
-    
-    renderGL = False
 
     # Pixmaps to use for double buffering
     pixmap = None
     dynamicPixmap = None
     
+    # Flag to show if this scene is to be rendered using OpenGL
+    renderGL = False
+    
     # TODO...
     __glDrawable = None
     
@@ -58,10 +67,9 @@ class GtkViewArea(gtk.DrawingArea):
         
         self.view = view
 
-	gnome.program_init('glchess',VERSION,
-                           properties={gnome.PARAM_APP_DATADIR:APP_DATA_DIR}
-                           )
-
+        if haveGnomeSupport:
+            gnome.program_init('glchess', VERSION,
+                               properties={gnome.PARAM_APP_DATADIR: APP_DATA_DIR})
 
         # Allow notification of button presses
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.BUTTON_RELEASE_MASK | gtk.gdk.BUTTON_MOTION_MASK)
@@ -83,10 +91,10 @@ class GtkViewArea(gtk.DrawingArea):
         """Request this widget is redrawn"""
         #FIXME: Check this is valid
         self.window.invalidate_rect(self.allocation, False)
-        
+
     def setRenderGL(self, renderGL):
         """Enable OpenGL rendering"""
-        if not hasattr(gtk, 'gtkgl'):
+        if not haveGLSupport:
             renderGL = False
         
         if self.renderGL == renderGL:
@@ -113,8 +121,7 @@ class GtkViewArea(gtk.DrawingArea):
             return
         
         self.__glDrawable = glDrawable
-        
-        import OpenGL
+
         if not self.view.ui.openGLInfoPrinted:
             print 'Using OpenGL:'
             print 'VENDOR=' + OpenGL.GL.glGetString(OpenGL.GL.GL_VENDOR)
@@ -155,7 +162,7 @@ class GtkViewArea(gtk.DrawingArea):
             try:
                 if self.view.feedback is not None:
                     self.view.feedback.renderGL()
-            except GLerror, e:
+            except OpenGL.GLerror, e:
                 print 'Rendering Error: ' + str(e)
                 traceback.print_exc(file = sys.stdout)
 
@@ -209,6 +216,9 @@ class GtkView(glchess.ui.ViewController):
     # The UI this view belongs to
     ui            = None
     
+    # The title of this view
+    title         = None
+    
     # The widget to render the scene to
     widget        = None
     
@@ -216,13 +226,14 @@ class GtkView(glchess.ui.ViewController):
     moveModel    = None
     selectedMove = -1
     
-    def __init__(self, ui, feedback, isActive = True):
+    def __init__(self, ui, title, feedback, isActive = True):
         """Constructor for a view.
         
         'feedback' is the feedback object for this view (extends ui.ViewFeedback).
         'isActive' is a flag showing if this view can be controlled by the user (True) or not (False).
         """
         self.ui = ui
+        self.title = title
         self.feedback = feedback
         self.isActive = isActive
         self.widget = GtkViewArea(self)
@@ -274,7 +285,7 @@ class GtkView(glchess.ui.ViewController):
         self.selectedMove = moveNumber
         if self.feedback is not None:
             self.feedback.setMoveNumber(moveNumber)
-        
+
 class GtkGameNotebook(gtk.Notebook):
     """
     """
@@ -282,12 +293,14 @@ class GtkGameNotebook(gtk.Notebook):
     glConfig          = None
 
     defaultView       = None
+    views             = None
     viewsByWidget     = None
     
     def __init__(self, ui):
         """
         """
         self.ui = ui
+        self.views = []
         self.viewsByWidget = {}
         
         gtk.Notebook.__init__(self)
@@ -315,7 +328,7 @@ class GtkGameNotebook(gtk.Notebook):
         """
         """
         assert(self.defaultView is None)
-        self.defaultView = GtkView(self.ui, feedback)
+        self.defaultView = GtkView(self.ui, '', feedback)
         page = self.append_page(self.defaultView.widget)
         self.set_current_page(page)
         
@@ -326,7 +339,8 @@ class GtkGameNotebook(gtk.Notebook):
     def addView(self, title, feedback):
         """
         """
-        view = GtkView(self.ui, feedback)
+        view = GtkView(self.ui, title, feedback)
+        self.views.append(view)
         self.viewsByWidget[view.widget] = view
         page = self.append_page(view.widget)
         self.set_tab_label_text(view.widget, title)
@@ -336,25 +350,19 @@ class GtkGameNotebook(gtk.Notebook):
         
         return view
     
-    def getView(self, pageNumber = None):
-        """Get the view at a given page number.
+    def getView(self):
+        """Get the currently selected view.
         
-        'pageNumber' is the page to check or None to get the selected page.
-        
-        Return the view (GtkView) on this page or None if no view here.
+        Returns the view (GtkView) on this page or None if no view here.
         """
-        if pageNumber is None:
-            # If splashscreen present then there is no view
-            if len(self.viewsByWidget) > 0:
-                num = self.get_current_page()
-                if num < 0:
-                    return None
-                widget = self.get_nth_page(num)
-            else:
-                return None
-        else:
-            widget = self.get_nth_page(pageNumber)
-            
+        # If splashscreen present then there is no view
+        if len(self.viewsByWidget) == 0:
+            return None
+        
+        num = self.get_current_page()
+        if num < 0:
+            return None
+        widget = self.get_nth_page(num)
         return self.viewsByWidget[widget]
     
     def removeView(self, view):
@@ -363,6 +371,7 @@ class GtkGameNotebook(gtk.Notebook):
         'view' is the view to remove.
         """
         self.remove_page(self.page_num(view.widget))
+        self.views.remove(view)
         self.viewsByWidget.pop(view.widget)
         self.__updateTabVisibleState()
 
@@ -448,6 +457,54 @@ class AIView:
         if self.window.pageCount == 0:
             self.window.defaultPage.show()
             self.window.notebook.set_show_tabs(False)
+            
+class SaveDialog:
+    """
+    """
+
+    def __init__(self, ui):
+        """Constructor"""
+        self.ui = ui
+        self.model = gtk.ListStore(gobject.TYPE_PYOBJECT, gobject.TYPE_BOOLEAN, str)
+        
+        self.view = ui._gui.get_widget('save_games_treeview')
+        self.view.set_model(self.model)
+        
+        selection = self.view.get_selection()
+        selection.set_mode(gtk.SELECTION_NONE)
+
+        cell = gtk.CellRendererToggle()
+        cell.set_property('activatable', True)
+        cell.connect('toggled', self._toggle_cb)
+        column = gtk.TreeViewColumn('Save', cell)
+        column.add_attribute(cell, 'active', 1)
+        self.view.append_column(column)
+        
+        cell = gtk.CellRendererText()
+        column = gtk.TreeViewColumn('Game', cell)
+        column.add_attribute(cell, 'text', 2)
+        self.view.append_column(column)
+        
+    def setViews(self, views):
+        """
+        """
+        self.model.clear()
+        for view in views:
+            iter = self.model.append()
+            self.model.set(iter, 0, view, 1, True, 2, view.title)
+
+    def setVisible(self, isVisible):
+        """
+        """
+        widget = self.ui._gui.get_widget('save_dialog')
+        if isVisible:
+            widget.show_all()
+        else:
+            widget.hide()
+            
+    def _toggle_cb(self, widget, path, data = None):
+        """Gtk+ callback"""
+        self.model[path][1] = not self.model[path][1]
 
 class GtkUI(glchess.ui.UI):
     """
@@ -471,10 +528,6 @@ class GtkUI(glchess.ui.UI):
     # Dictionary of save game dialogs keyed by view
     __saveGameDialogs = None
     
-    # Dictionary of configuration options
-    __config          = None
-    __applyingConfig  = False
-    
     __renderGL        = False
     openGLInfoPrinted = False
 
@@ -524,12 +577,16 @@ class GtkUI(glchess.ui.UI):
         if not hasattr(gtk, 'gtkgl'):
             self._gui.get_widget('menu_view_3d').set_sensitive(False)
         
-        # Load UI preferences
-        self.__config = {}
-        self.__loadConfig()
-        
         self.defaultViewController.widget.setRenderGL(self.__renderGL)
 
+        self.saveDialog = SaveDialog(self)
+        
+        # Watch for config changes
+        glchess.config.watch('show_toolbar', self.__applyConfig)
+        glchess.config.watch('show_history', self.__applyConfig)
+        glchess.config.watch('fullscreen', self.__applyConfig)
+        glchess.config.watch('show_3d', self.__applyConfig)
+
     # Public methods
     
     def watchFileDescriptor(self, fd):
@@ -547,7 +604,7 @@ class GtkUI(glchess.ui.UI):
         """
         iconTheme = gtk.icon_theme_get_default()
         try:
-            icon = iconTheme.load_icon("stock_notebook", 24, gtk.ICON_LOOKUP_USE_BUILTIN)
+            icon = iconTheme.load_icon('stock_notebook', 24, gtk.ICON_LOOKUP_USE_BUILTIN)
         except gobject.GError:
             icon = None
         iter = self.__playerModel.append()
@@ -577,7 +634,11 @@ class GtkUI(glchess.ui.UI):
         """Run the UI.
         
         This method will not return.
-        """        
+        """
+        # Load configuration
+        for name in ['show_toolbar', 'show_history', 'fullscreen', 'show_3d']:
+            self.__applyConfig(name, glchess.config.get(name))
+        
         gtk.main()
         
     # Extended methods
@@ -631,90 +692,52 @@ class GtkUI(glchess.ui.UI):
         self._updateViewButtons()
 
     # Private methods
-    
-    def __loadConfig(self):
-        """
-        """
-        # Set defaults
-        self.__config = {'show_toolbar': 'True',
-                         'show_history': 'True',
-                         'show_3d': 'False'}
-        
-        name = os.path.expanduser('~/.glchess/gtkui.ini')
-        cp = ConfigParser.ConfigParser()
-        cp.read(name)
-        
-        try:
-            items = cp.items('ui')
-        except ConfigParser.NoSectionError:
-            self.__saveConfig()
-        else:
-            for (name, value) in items:
-                self.__config[name] = value
 
-        self.__applyConfig()
-
-    def __setConfig(self, name, value):
+    def __applyConfig(self, name, value):
         """
         """
-        if self.__applyingConfig:
-            return
-        
-        self.__config[name] = value
-        self.__applyConfig()
-        self.__saveConfig()
-        
-    def __saveConfig(self):
-        """
-        """
-        name = os.path.expanduser('~/.glchess/gtkui.ini')
-        try:
-            f = file(name, 'w')
-        except IOError, e:
-            print 'Unable to save config: ' + str(e)
-            return
-        
-        cp = ConfigParser.ConfigParser()
-        cp.add_section('ui')
-        for (name, value) in self.__config.iteritems():
-            cp.set('ui', name, value)
-        cp.write(f)
-        
-    def __applyConfig(self):
-        """
-        """
-        # Stop recursion
-        self.__applyingConfig = True
-        
         # Show/hide the toolbar
-        toolbar = self.__getWidget('toolbar')
-        menu = self.__getWidget('menu_view_toolbar')
-        if self.__config['show_toolbar'] == 'True':
-            menu.set_active(True)
-            toolbar.show()
-        else:
-            menu.set_active(False)
-            toolbar.hide()
+        if name == 'show_toolbar':
+            toolbar = self.__getWidget('toolbar')
+            menu = self.__getWidget('menu_view_toolbar')
+            if value is True:
+                menu.set_active(True)
+                toolbar.show()
+            else:
+                menu.set_active(False)
+                toolbar.hide()
             
         # Show/hide the history
-        box = self.__getWidget('navigation_box')
-        menu = self.__getWidget('menu_view_history')
-        if self.__config['show_history'] == 'True':
-            menu.set_active(True)
-            box.show()
-        else:
-            menu.set_active(False)
-            box.hide()
+        elif name == 'show_history':
+            box = self.__getWidget('navigation_box')
+            menu = self.__getWidget('menu_view_history')
+            if value is True:
+                menu.set_active(True)
+                box.show()
+            else:
+                menu.set_active(False)
+                box.hide()
+                
+        # Fullscreen mode
+        elif name == 'fullscreen':
+            window = self._gui.get_widget('glchess_app')
+            if value is True:
+                window.fullscreen()
+                self._gui.get_widget('menu_fullscreen').hide()
+                self._gui.get_widget('menu_leave_fullscreen').show()
+            else:
+                window.unfullscreen()
+                self._gui.get_widget('menu_leave_fullscreen').hide()
+                self._gui.get_widget('menu_fullscreen').show()
 
         # Enable/disable OpenGL rendering
-        self.__renderGL = self.__config['show_3d'] == 'True'
-        menuItem = self.__getWidget('menu_view_3d')
-        menuItem.set_active(self.__renderGL)
-        self.notebook.defaultView.widget.setRenderGL(self.__renderGL)
-        for view in self.notebook.viewsByWidget.itervalues():
-            view.widget.setRenderGL(self.__renderGL)
-            
-        self.__applyingConfig = False
+        elif name == 'show_3d':
+            self.__renderGL = value
+            menuItem = self.__getWidget('menu_view_3d')
+            menuItem.set_active(self.__renderGL)
+            self.notebook.defaultView.widget.setRenderGL(self.__renderGL)
+            for view in self.notebook.views:
+                view.widget.setRenderGL(self.__renderGL)
         
     def startAnimation(self):
         """Start the animation callback"""
@@ -747,26 +770,26 @@ class GtkUI(glchess.ui.UI):
     def _on_show_toolbar_clicked(self, widget, data = None):
         """Gtk+ callback"""
         if widget.get_active():
-            value = 'True'
+            value = True
         else:
-            value = 'False'
-        self.__setConfig('show_toolbar', value)
+            value = False
+        glchess.config.set('show_toolbar', value)
 
     def _on_show_history_clicked(self, widget, data = None):
         """Gtk+ callback"""
         if widget.get_active():
-            value = 'True'
+            value = True
         else:
-            value = 'False'
-        self.__setConfig('show_history', value)
+            value = False
+        glchess.config.set('show_history', value)
 
     def _on_toggle_3d_clicked(self, widget, data = None):
         """Gtk+ callback"""
         if widget.get_active():
-            value = 'True'
+            value = True
         else:
-            value = 'False'
-        self.__setConfig('show_3d', value)
+            value = False
+        glchess.config.set('show_3d', value)
 
     def _on_show_ai_stats_clicked(self, widget, data = None):
         """Gtk+ callback"""
@@ -854,12 +877,13 @@ class GtkUI(glchess.ui.UI):
         self.__getWidget('end_game_button').set_sensitive(enableWidgets)
         self.__getWidget('save_game_button').set_sensitive(enableWidgets)
         self.__getWidget('menu_save_item').set_sensitive(enableWidgets)
+        self.__getWidget('menu_save_as_item').set_sensitive(enableWidgets)
         self.__getWidget('menu_end_game_item').set_sensitive(enableWidgets)
 
         combo = self.__getWidget('history_combo')
-        if view is None: 
-	    if combo.get_model() != None:
-	        combo.set_model(None)
+        if view is None:
+            if combo.get_model() != None:
+                combo.set_model(None)
         else:
             (model, selected) = view._getModel()
             combo.set_model(model)
@@ -891,9 +915,17 @@ class GtkUI(glchess.ui.UI):
     def _on_save_game_button_clicked(self, widget, data = None):
         """Gtk+ callback"""
         view = self.notebook.getView()
-        if not self.__saveGameDialogs.has_key(view):
-            self.__saveGameDialogs[view] = dialogs.GtkSaveGameDialog(self, view)
         
+        if view.feedback.getFileName() is not None:
+            view.feedback.save()
+        elif not self.__saveGameDialogs.has_key(view):
+            self.__saveGameDialogs[view] = dialogs.GtkSaveGameDialog(self, view)
+            
+    def _on_save_as_game_button_clicked(self, widget, data = None):
+        view = self.notebook.getView()
+        if not self.__saveGameDialogs.has_key(view):
+            self.__saveGameDialogs[view] = dialogs.GtkSaveGameDialog(self, view, view.feedback.getFileName())
+
     def _on_end_game_button_clicked(self, widget, data = None):
         """Gtk+ callback"""
         view = self.notebook.getView()
@@ -904,20 +936,14 @@ class GtkUI(glchess.ui.UI):
     def _on_help_clicked(self, widget, data = None):
         """Gtk+ callback"""
         gnome.help_display('glchess')
-        
+
     def _on_view_fullscreen_clicked(self, widget, data = None):
         """Gtk+ callback"""
-        window = self._gui.get_widget('glchess_app')
-        window.fullscreen()
-        self._gui.get_widget('menu_fullscreen').hide()
-        self._gui.get_widget('menu_leave_fullscreen').show()
+        glchess.config.set('fullscreen', True)
         
     def _on_view_unfullscreen_clicked(self, widget, data = None):
         """Gtk+ callback"""
-        window = self._gui.get_widget('glchess_app')
-        window.unfullscreen()
-        self._gui.get_widget('menu_leave_fullscreen').hide()
-        self._gui.get_widget('menu_fullscreen').show()
+        glchess.config.set('fullscreen', False)
 
     def _on_about_clicked(self, widget, data = None):
         """Gtk+ callback"""
@@ -937,10 +963,42 @@ class GtkUI(glchess.ui.UI):
         
         # Stop the event - the window will be closed by the menu event
         return True
+   
+    def _on_save_dialog_response(self, widget, response_id, data = None):
+        """Gtk+ callback"""
+        self.saveDialog.setVisible(False)
+        
+        if response_id != gtk.RESPONSE_OK:
+            return
+        
+        # Save the requested games
+        for (view, save, _) in self.saveDialog.model:
+            if save:
+                view.feedback.save()
+
+        self.onQuit()
+        
+    def _on_save_dialog_delete(self, widget, data = None):
+        """Gtk+ callback"""
+        # Leave it to use to hide the dialog
+        return True
 
     def _on_quit(self, widget, data = None):
         """Gtk+ callback"""
-        self.onQuit()
+        # Check if any views need saving
+        viewsToSave = []
+        for view in self.notebook.views:
+            if view.feedback.needsSaving():
+                viewsToSave.append(view)
+             
+        if len(viewsToSave) == 0:
+            self.onQuit()
+        else:
+            self.saveDialog.setViews(viewsToSave)
+            self.saveDialog.setVisible(True)
+
+        # Don't close the window, we will do it ourself
+        return True
 
 if __name__ == '__main__':
     ui = GtkUI()
