@@ -31,32 +31,33 @@
 
 G_DEFINE_TYPE (GamesPreimage, games_preimage, G_TYPE_OBJECT);
 
-static void 
-games_preimage_init (GamesPreimage *preimage) 
+static void
+games_preimage_init (GamesPreimage * preimage)
 {
-  preimage->scalable  = FALSE;
-  preimage->srcsize   = 0;
-  preimage->width     = 0;
-  preimage->height    = 0;
-  preimage->pixbuf    = NULL;
+  preimage->scalable = FALSE;
+  preimage->srcsize = 0;
+  preimage->width = 0;
+  preimage->height = 0;
+  preimage->pixbuf = NULL;
   preimage->srcbuffer = NULL;
 }
 
 static void
-games_preimage_finalize (GamesPreimage *preimage)
+games_preimage_finalize (GamesPreimage * preimage)
 {
   g_free (preimage->srcbuffer);
-  if (preimage->pixbuf != NULL) g_object_unref (preimage->pixbuf);
+  if (preimage->pixbuf != NULL)
+    g_object_unref (preimage->pixbuf);
 }
 
-static void 
-games_preimage_class_init (GamesPreimageClass *klass)
+static void
+games_preimage_class_init (GamesPreimageClass * klass)
 {
   GObjectClass *oclass = G_OBJECT_CLASS (klass);
   oclass->finalize = (GObjectFinalizeFunc) games_preimage_finalize;
 }
 
-GamesPreimage * 
+GamesPreimage *
 games_preimage_new (void)
 {
   return GAMES_PREIMAGE (g_object_new (GAMES_TYPE_PREIMAGE, NULL));
@@ -65,87 +66,81 @@ games_preimage_new (void)
 /* size_prepared_cb:
  * Handles the size-prepared signal in games_preimage_render */
 static void
-size_prepared_cb (GdkPixbufLoader *loader,
-		  gint              width,   
-		  gint              height,
-		  gpointer         data)
+size_prepared_cb (GdkPixbufLoader * loader,
+		  gint width, gint height, gpointer data)
 {
   struct {
     gint width;
     gint height;
   } *info = data;
-  
-  width  = info->width;
+
+  width = info->width;
   height = info->height;
   gdk_pixbuf_loader_set_size (loader, width, height);
-}                                                                              
+}
 
 /* games_preimage_render:
  * Create a GdkPixbuf from a GamesPreimage at the specified
  * width and height. */
 GdkPixbuf *
 games_preimage_render (GamesPreimage * preimage,
-                       gint width, 
-		       gint height, 
-		       GError **error)
+		       gint width, gint height, GError ** error)
 {
-  GdkPixbuf * pixbuf;
-  
+  GdkPixbuf *pixbuf;
+
   g_return_val_if_fail (width > 0 && height > 0, NULL);
   g_return_val_if_fail (preimage != NULL, NULL);
-  
-  if (preimage->scalable){   /* Render vector image */
-    
+
+  if (preimage->scalable) {	/* Render vector image */
+
     GdkPixbufLoader *loader;
 
     struct {
       gint width;
       gint height;
     } info;
-    
-    guchar *buffer     = preimage->srcbuffer;
-    gsize  buffer_size = preimage->srcsize;
-    
-    info.width  = width;
+
+    guchar *buffer = preimage->srcbuffer;
+    gsize buffer_size = preimage->srcsize;
+
+    info.width = width;
     info.height = height;
 
     loader = gdk_pixbuf_loader_new ();
-    
-    g_signal_connect (loader, "size-prepared", 
+
+    g_signal_connect (loader, "size-prepared",
 		      G_CALLBACK (size_prepared_cb), &info);
-    
+
     if (!gdk_pixbuf_loader_write (loader, buffer, buffer_size, error)) {
       gdk_pixbuf_loader_close (loader, NULL);
       g_object_unref (loader);
       return NULL;
     }
 
-    if (!gdk_pixbuf_loader_close (loader, error)) {        	
+    if (!gdk_pixbuf_loader_close (loader, error)) {
       g_object_unref (loader);
       return NULL;
     }
-    
+
     pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-    
+
     if (!pixbuf) {
       g_object_unref (loader);
       g_set_error (error,
 		   GDK_PIXBUF_ERROR,
-		   GDK_PIXBUF_ERROR_FAILED,
-		   _("Image rendering failed."));
+		   GDK_PIXBUF_ERROR_FAILED, _("Image rendering failed."));
       return NULL;
     }
-    
+
     g_object_ref (pixbuf);
     g_object_unref (loader);
-    
-  } else {                   /* Render raster image */
+
+  } else {			/* Render raster image */
 
     pixbuf = gdk_pixbuf_scale_simple (preimage->pixbuf,
-				      width, height,
-				      GDK_INTERP_BILINEAR);
-  } 
-  
+				      width, height, GDK_INTERP_BILINEAR);
+  }
+
   return pixbuf;
 }
 
@@ -153,19 +148,18 @@ games_preimage_render (GamesPreimage * preimage,
  * Take a filename and use it to create a GamesPreimage, which can
  * be used to render a GdkPixbuf later. */
 GamesPreimage *
-games_preimage_new_from_file (const gchar *filename, 
-			      GError     **error)
+games_preimage_new_from_file (const gchar * filename, GError ** error)
 {
-  GamesPreimage   *preimage;
-  GdkPixbuf       *pixbuf;
+  GamesPreimage *preimage;
+  GdkPixbuf *pixbuf;
   GdkPixbufFormat *format;
-  
+
   struct {
-    gint      width;
-    gint      height;
+    gint width;
+    gint height;
     gboolean scalable;
   } info;
-  
+
   g_return_val_if_fail (filename != NULL, NULL);
 
   format = gdk_pixbuf_get_file_info (filename, &info.width, &info.height);
@@ -178,39 +172,39 @@ games_preimage_new_from_file (const gchar *filename,
 
   info.scalable = gdk_pixbuf_format_is_scalable (format);
 
-  if (info.scalable) {   /* Prepare a vector image... */
+  if (info.scalable) {		/* Prepare a vector image... */
 
-    preimage = games_preimage_new();
-    
-    preimage->scalable  = info.scalable;
-    preimage->width     = info.width;
-    preimage->height    = info.height;
+    preimage = games_preimage_new ();
+
+    preimage->scalable = info.scalable;
+    preimage->width = info.width;
+    preimage->height = info.height;
 
     if (!g_file_get_contents (filename,
-			      (gchar **)(char *)&(preimage->srcbuffer), 
+			      (gchar **) (char *) &(preimage->srcbuffer),
 			      &(preimage->srcsize), error)) {
       g_object_unref (preimage);
       return NULL;
     }
-    
-  } else {              /* ...Or prepare a raster image */
+
+  } else {			/* ...Or prepare a raster image */
     pixbuf = gdk_pixbuf_new_from_file (filename, error);
-       
+
     if (!pixbuf) {
       return NULL;
     }
-    
+
     g_object_ref (pixbuf);
-    
+
     preimage = games_preimage_new ();
-    
+
     preimage->scalable = info.scalable;
-    preimage->pixbuf   = pixbuf;
-    preimage->width    = info.width;
-    preimage->height   = info.height;
+    preimage->pixbuf = pixbuf;
+    preimage->width = info.width;
+    preimage->height = info.height;
   }
-  
-  return preimage;	
+
+  return preimage;
 }
 
 gboolean
@@ -237,16 +231,16 @@ games_preimage_get_height (GamesPreimage * preimage)
 GdkPixbuf *
 games_preimage_render_unscaled_pixbuf (GamesPreimage * preimage)
 {
-  GdkPixbuf * unscaled_pixbuf;
-  
+  GdkPixbuf *unscaled_pixbuf;
+
   g_return_val_if_fail (preimage != NULL, NULL);
-  
+
   if ((unscaled_pixbuf = preimage->pixbuf)) {
     g_object_ref (unscaled_pixbuf);
   } else {
     unscaled_pixbuf = games_preimage_render (preimage, preimage->width,
-                                             preimage->height, NULL);
+					     preimage->height, NULL);
   }
-  
+
   return unscaled_pixbuf;
 }
